Comparators<T> mixin
Adds comparison operators to a comparable class with a total order.
- Implemented types
-
- Comparable<
T>
- Comparable<
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
T other) → int -
Compares this object to another object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator <(
T other) → bool -
Whether this
Tis numerically smaller thanother. -
operator <=(
T other) → bool -
Whether this
Tis numerically smaller than or equal toother. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
T other) → bool -
Whether this
Tis numerically greater thanother. -
operator >=(
T other) → bool -
Whether this
Tis numerically greater than or equal toother.