operator <= method
Whether this T is numerically smaller than or equal to other.
Implementation
bool operator <=(T other) => compareTo(other) <= 0;
Whether this T is numerically smaller than or equal to other.
bool operator <=(T other) => compareTo(other) <= 0;