EnglishAccidentalNotation class final

The English notation system for Accidental.

Inheritance

Constructors

EnglishAccidentalNotation({bool showNatural = true})
Creates a new EnglishAccidentalNotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
regExp RegExp
The regular expression for matching V.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNatural bool
Whether a natural Note should be represented with the Accidental.natural symbol.
final

Methods

format(Accidental accidental) String
Formats this V.
override
matches(String source) bool
Whether source can be parsed with parse.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String source) Accidental
Parses source as V.
inherited
parseMatch(RegExpMatch match) Accidental
Parses match from regExp as V.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited