Respellable<T> mixin
A mixin for anything that can be respelled.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- respelledDownwards → T
-
This
Trespelled downwards while keeping the same number of semitones.no setter - respelledSimple → T
-
This
Twith the simplest spelling while keeping the same number of semitones.no setter - respelledUpwards → T
-
This
Trespelled upwards while keeping the same number of semitones.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited