respelledDownwards property
T
get
respelledDownwards
This T respelled downwards while keeping the same number of semitones.
Implementation
T get respelledDownwards;
This T respelled downwards while keeping the same number of semitones.
T get respelledDownwards;