EnharmonicSpellingsPitchClassNotation class final
The StringNotationSystem for enharmonic spellings PitchClass.
See Tonal counterparts.
- Inheritance
-
- Object
- NotationSystem<
PitchClass, String> - StringNotationSystem<
PitchClass> - EnharmonicSpellingsPitchClassNotation
Constructors
-
EnharmonicSpellingsPitchClassNotation({StringNotationSystem<
Note> noteNotation = const EnglishNoteNotation.symbol()}) -
Creates a new EnharmonicSpellingsPitchClassNotation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
noteNotation
→ StringNotationSystem<
Note> -
The StringNotationSystem for Note.
final
- regExp → RegExp
-
The regular expression for matching
V.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
PitchClass pitchClass) → String -
Formats this
V.override -
matches(
String source) → bool -
Whether
sourcecan be parsed with parse.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String source) → PitchClass -
Parses
sourceasV.inherited -
parseMatch(
RegExpMatch match) → PitchClass -
Parses
matchfrom regExp asV.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited