MusicXmlPitchNotation class
The MusicXML representation of a Pitch.
- Inheritance
-
- Object
- NotationSystem<
Pitch, XmlDocument> - MusicXmlPitchNotation
Constructors
-
MusicXmlPitchNotation({StringNotationSystem<
NoteName> noteNameNotation = const EnglishNoteNameNotation()}) -
Creates a new MusicXmlPitchNotation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
noteNameNotation
→ StringNotationSystem<
NoteName> -
The StringNotationSystem for NoteName.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
Pitch pitch) → XmlDocument -
Formats this
I.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
XmlDocument source) → Pitch -
Parses
sourceasI.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited